/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.appwithinminutes.test.ui;

import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.xwiki.appwithinminutes.test.po.AppWithinMinutesHomePage;
import org.xwiki.appwithinminutes.test.po.ApplicationClassEditPage;
import org.xwiki.appwithinminutes.test.po.ApplicationCreatePage;
import org.xwiki.appwithinminutes.test.po.ApplicationHomeEditPage;
import org.xwiki.appwithinminutes.test.po.ApplicationHomePage;
import org.xwiki.appwithinminutes.test.po.EntryEditPage;
import org.xwiki.appwithinminutes.test.po.EntryNamePane;
import org.xwiki.test.docker.junit5.TestReference;
import org.xwiki.test.docker.junit5.UITest;
import org.xwiki.test.ui.TestUtils;
import org.xwiki.test.ui.XWikiWebDriver;
import org.xwiki.test.ui.po.ViewPage;

import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Tests the application wizard.
 *
 * @version $Id: dee87f044fc658e0dea1f0a58fcf10cd3be2ad16 $
 * @since 12.5
 */
@UITest
public class WizardIT
{
    private static final String USER_NAME = "Wizard";

    private static final String PASSWORD = "password";

    @BeforeAll
    static void beforeAll(TestUtils testUtils)
    {
        testUtils.loginAsSuperAdmin();
        // The application creator needs script rights in order to execute the scripts generated by the wizard.
        testUtils.setGlobalRights("", "XWiki." + USER_NAME, "script", true);
        testUtils.createUser(USER_NAME, PASSWORD, "");
    }

    @Order(1)
    @Test
    void createApplicationWhenDefaultWikiSyntaxIsPlain(TestReference testReference, TestUtils testUtils,
        XWikiWebDriver driver) throws Exception
    {
        testUtils.loginAsSuperAdmin();
        String defaultDocSyntax = testUtils.setWikiPreference("core.defaultDocumentSyntax", "plain/1.0");

        String appName = testReference.getLastSpaceReference().getName();
        AppWithinMinutesHomePage.gotoPage().deleteApplication(appName);

        testUtils.login(USER_NAME, PASSWORD);

        try {
            ApplicationCreatePage appCreatePage = AppWithinMinutesHomePage.gotoPage().clickCreateApplication();
            appCreatePage.setApplicationName(appName);
            ApplicationClassEditPage classEditPage = appCreatePage.clickNextStep();
            classEditPage.addField("Short Text");

            ApplicationHomeEditPage appHomeEditPage = classEditPage.clickNextStep().clickNextStep();
            appHomeEditPage.setDescription("one **two** three");

            ApplicationHomePage appHomePage = appHomeEditPage.clickFinish();
            // Verify that the application home page was created with the right syntax.
            assertTrue(driver.getPageSource().contains("one <strong>two</strong> three"),
                "The application description is not rendered properly on the application home page.");

            EntryNamePane entryNamePage = appHomePage.clickAddNewEntry();
            entryNamePage.setName("Test");

            EntryEditPage entryEditPage = entryNamePage.clickAdd();
            String value = "0123456789";
            entryEditPage.setValue("shortText1", value);

            ViewPage entryViewPage = entryEditPage.clickSaveAndView();
            // Verify that the application sheet was created with the right syntax.
            assertTrue(entryViewPage.getContent().contains(value),
                "The entry view page doesn't display the property value.");
        } finally {
            // Restore the default document syntax.
            testUtils.loginAsSuperAdmin();
            testUtils.setWikiPreference("core.defaultDocumentSyntax", defaultDocSyntax);
        }
    }
}
